@@ -6,7 +6,6 @@ from psycopg2 import connect as psycopg2_connect
 from csv import QUOTE_NONNUMERIC
 from pyspark.sql.session import SparkSession
 from pyspark.sql.dataframe import DataFrame as SparkDF
-from pandas import DataFrame as PandasDF
 from .S3File import S3Files
 
 
@@ -103,7 +102,7 @@ class S3:
 		path = self._get_absolute_path(path)
 		return self.file_system.exists(path=path)
 
-	def write(self, path, bytes):
+	def write_bytes(self, path, bytes):
 		path = self._get_absolute_path(path)
 		with self.file_system.open(path=path, mode='wb') as f:
 			f.write(bytes)
@@ -125,7 +124,7 @@ class S3:
 		bytes = data.to_csv(path_or_buf=None, quoting=QUOTE_NONNUMERIC, index=index, **kwargs).encode(encoding)
 		self.write(path=path, bytes=bytes)
 
-	def read(self, path):
+	def read_bytes(self, path):
 		with self.file_system.open(path=self._root+path, mode='rb') as f:
 			result = f.read()
 		return result
@@ -319,7 +318,7 @@ class S3:
 	load_pickle = read_pickle
 	save_pickle = write_pickle
 
-	def write(self, obj, path, mode='overwrite'):
+	def save(self, obj, path, mode='overwrite'):
 		"""
 		writes an object to path as a parquet if the object is a Spark DataFrame or a pickle otherwise
 		:type obj: object
@@ -345,7 +344,7 @@ class S3:
 
 			return self.write_pickle(obj=obj, path=path, mode=mode)
 
-	def read(self, path, spark=None):
+	def load(self, path, spark=None):
 		"""
 		reads an object from a path. If the extension is .parquet then the object is assumed to be a Spark DataFrame
 		and the read_parquet method is used, otherwise a pickle will be read.
@@ -360,4 +359,4 @@ class S3:
 			return self.read_pickle(path=path)
 
 		else:
-			raise NotImplementedError(f'read is not implemented for {path}!')
+			raise NotImplementedError(f'load is not implemented for {path}!')
